# Table of Contents

- [google-cloud-platform-modeling-best-practices](<./google-cloud-platform-modeling-best-practices.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Google Cloud Platform Modeling Best Practices](<./Google-Cloud-Platform-Modeling-Best-Practices.md>)
